﻿#!/usr/bin/python
# -*- coding: utf-8 -*-

import os
import pat

def getScriptPath():
   PAT = str(pat).split()[3][1:-2]
   return os.path.dirname(PAT)

def DebugLog(msg):
   if os.environ.has_key('DEBUG'):
      print unicode(msg).encode('utf-8')

def DebugFile(msg, filename=''):
   if not filename:
      filename = 'debug.log'
   if os.environ.has_key('DEBUG'):
      f = open(filename, 'a')
      f.write(unicode(msg).encode('utf-8'))
      f.close()
